from base import Base

class Catalog(Base):
	
    def __init__(self, apikey):
        Base.__init__(self, apikey)
        self.url = "/".join((self.ENDPOINT, "catalog"))
              	
    def search(self, string, **params):
        payload  = self.build_payload(params, { 'search': string })
        response = self.get(self.url, params=payload)
        return response['Products']['List']


from distutils.core import setup

setup(
    name='wino',
    version='0.0.1',
    author='Scott M. Cruwys',
    author_email='scruwys@gmail.com',
    packages=['wino', 'wino.tests'],
    url='http://pypi.python.org/pypi/wino/',
    license='LICENSE.txt',
    description='Wine.com API wrapper',
)


import requests as req

class Base(object):

    ENDPOINT = 'http://services.wine.com/api/beta2/service.svc/json'

    def __init__(self, apikey):
        self.apikey = { 'apikey': apikey }

    def get(self, url, **params):
        payload  = self.build_payload(self.apikey, params['params'])
        response = req.get(url, params=payload)
        return response.json()

    def build_payload(self, *params):
        res = {}
        for p in params:
            res.update(p.items())
        return res